@@ -5,7 +5,7 @@ use 5.010_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.025';
+our $VERSION = '0.026';
 my $version = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -23,21 +23,6 @@ require TAP::Parser::Aggregator if 0;
 require TAP::Parser::Multiplexer if 0;
 require TAP::Formatter::Console::ParallelSession if 0;
 
-# this looks weird, I know - see https://rt.cpan.org/Public/Bug/Display.html?id=56862
-#
-# I seem to hit the problem with "Warning: Name "Config::Std::Hash::DEMOLISH" used only once..."
-# when running a Par::Packer binary but not when as a 'normal' script.
-#
-# The below incantation seem to get rid of that, at least for now. Let's see if it reappears... 
-#
-if ($IS_PACKED)
-{
-	my $dummy1 = '';
-	read_config(\$dummy1, my %cfg);
-	my $dummy2 = *Config::Std::Hash::DEMOLISH;
-	my $dummy3 = *Config::Std::Hash::DEMOLISH;
-}
-
 # main entry point
 #
 sub main
